function [r,sigbounds]=ACF(x,K)
%sample autocorrelation of time series x up to lag K
%SYNTAX
%[r,sigbounds]=ACF(x,K)
%INPUTS
%x is a vector (time series)
%K is max lag to use
%OUTPUTS
%r is the sample autocorrelation at lags 1...K
%sigbounds is a vector of approximate 95% significance bounds
%LICENSE
% This file is part of rsstatespace.
%
%    rsstatespace is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    stochmap is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with rsstatespace.  If not, see <http://www.gnu.org/licenses/>.
%
%See gpl-3.0.txt for full information.


r=zeros(K+1,1);
n=length(x);%number of observations
xc=x-mean(x);%centred
for k=0:K%for each lag k=0...K
    r(k+1)=sum(xc(1:n-k).*xc(k+1:n));%calculate n*c_k at lag k: formula from MASS p390 and Matlab help for autocorr 
end
r=r/n;%divide by n
r=r/r(1);%normalize: divide by c_0
r=r(2:K+1);%return vector of r_1...r_K
sigbounds=[-1 1]*1.96/sqrt(n);%approximate 95% significance bounds for autocorrelation function: page 71 in OU M249 book 2 (time series)
