function Xfull=Xfromv(v,X,tau,n)
%construct explanatory variable matrix for given shift model
%SYNTAX
%Xfull=Xfromv(v,X,tau,n)
%INPUTS
%v is a string specifying how the shift works: 3 elements. First
%element is 1 if there is a nonzero population growth rate, 0 otherwise. Second
%element is 1 if there is a step in abundance at time tau, 0
%otherwise. Third element is 1 if there is a change in population growth
%rate at time tau, 0 otherwise. e.g. v='010' for no growth, step change, no
%change in growth.
%X is explanatory variables (in columns), excluding terms for base growth
%rate and shift.
%tau is the shift time
%n is the number of observations
%OUTPUTS
%Xfull has the columns needed to specify the shift model as initial
%columns, followed by the columns in X
%LICENSE
% This file is part of rsstatespace.
%
%    rsstatespace is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    stochmap is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with rsstatespace.  If not, see <http://www.gnu.org/licenses/>.
%
%See gpl-3.0.txt for full information.

switch v
    case '000'
        Xfull=X;%no growth, no shift
    case '010'
        xs=zeros(n,1);
        xs(tau)=1;
        Xfull=[xs,X];%no growth, step change at tau
    case '100'
        Xfull=[ones(n,1),X];%growth, no shift
    case '110'
        xs=zeros(n,1);
        xs(tau)=1;
        Xfull=[ones(n,1),xs,X];%growth, step change at tau
    case '101'
        xg=[zeros(tau-1,1);ones(n-tau+1,1)];
        Xfull=[ones(n,1),xg,X];%growth, growth change at tau
    case '111'
        xs=zeros(n,1);
        xs(tau)=1;
        xg=[zeros(tau-1,1);ones(n-tau+1,1)];
        Xfull=[ones(n,1),xs,xg,X];%growth, step change at tau, growth change at tau
end
