function [beta,q]=kalman_diffuse_backparms2(theta)
%back transform parameters for univariate kalman filter model with
%explanatory variables and concentrated diffuse log likelihood
%SYNTAX
%[beta,q]=kalman_diffuse_backparms2(theta)
%INPUTS
%theta is a k+1 x 1 vector of parameters:
%k explanatory variable coefficients beta
%process error/measurement error q (q is log transformed)
%OUTPUTS
%beta,q (natural scale)
%LICENSE
% This file is part of rsstatespace.
%
%    rsstatespace is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    stochmap is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with rsstatespace.  If not, see <http://www.gnu.org/licenses/>.
%
%See gpl-3.0.txt for full information.

k1=length(theta);
beta=theta(1:k1-1);
q=exp(theta(k1));%back-transform q (it's restricted to the range [0, +infinity])

if isinf(q)%added 19/6/10, we had problems with inf values from line search
    q=1e9*sign(q);
end