function plausible=selectstatespace(pvalues,alpha)
%select among the 6 state-space models we examined: nesting structure is
%hard coded
%SYNTAX
%plausible=selectstatespace(pvalues,alpha)
%INPUTS
%pvalues is a vector of 7 p-values for the comparisons of nested models
%alpha is the size for each test
%OUTPUTS
%plausible is a binary vector with 1 if model i is plausible, i=1 (A) to 6
%(F)
%LICENSE
% This file is part of rsstatespace.
%
%    rsstatespace is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    stochmap is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with rsstatespace.  If not, see <http://www.gnu.org/licenses/>.
%
%See gpl-3.0.txt for full information.

plausible=[0,0,0,0,0,1];%models A to F. 1 means plausible
reject=(pvalues<=alpha);%which tests do we reject?

if(reject(1) && reject(2))
   %select F
else
    plausible(6)=0;%not F
    plausible(4)=~reject(1);%D plausible
    plausible(5)=~reject(2);%E plausible
end

if plausible(4)%consider D
   if (reject(3) && reject(4))
      %select D 
   else
       plausible(4)=0;%not D
       plausible(2)=~reject(3);%B plausible
       plausible(3)=~reject(4);%C plausible
   end
end

if plausible(5)%consider E
   if(reject(5))
       %select E
   else
       plausible(5)=0;
       plausible(3)=1;%C plausible (may also have been reached from D)
   end
end

if plausible(3)%consider C
   if(reject(7))
       %select C
   else
       plausible(3)=0;
       plausible(1)=1;%A plausible
   end
end

if plausible(2)%consider B
    if(reject(6))
        %select B
    else
        plausible(2)=0;
        plausible(1)=1;%A plausible
    end
end
